*Program to test filtering methods

clear

cd "C:\Users\gaheutel\Documents\Economics\RBCPollution\Empirical\CarbonBMB"

use monthlyrawco2data
*These are the raw aggregate emissions data from http://cdiac.esd.ornl.gov/trends/emis_mon/emis_mon_co2.html

tsset t, monthly

gen logco2emis = log( co2emissions)

clear

insheet using "C:\Users\gaheutel\Documents\Economics\RBCPollution\Empirical\X12\sa1.d11"
*These are the data that have been seasonally adjusted using the Census Bureau's X12ARIMA program: http://www.census.gov/srd/www/x12a/

drop in 1/2
rename v1 yearmonth
rename v2 co2emissionssa1
gen year = substr(yearmonth,1,4)
gen month = substr(yearmonth,5,2)
destring  co2emissionssa1 year month, replace

gen t = (year-1960)*12 + (month-1)
tsset t, monthly

merge year month using "C:\Users\gaheutel\Documents\Economics\RBCPollution\Empirical\CarbonBMB\monthlyrawco2data.dta", unique sort
drop _merge
save filtertestdata, replace

*Merge in with gdp data
clear
insheet using "C:\Users\gaheutel\Documents\Economics\RBCPollution\Empirical\CarbonBMB\gdpmonthly.txt", tab
drop in 1/1
rename v1 yearmonth
rename v2 gdp
gen year = substr(yearmonth,1,4)
gen month = substr(yearmonth,6,2)
destring  year month , replace
destring gdp, replace ignore(",")
drop yearmonth

merge year month using "C:\Users\gaheutel\Documents\Economics\RBCPollution\Empirical\CarbonBMB\filtertestdata.dta", unique sort
drop _merge
save filtertestdata, replace

tsset

gen lngdp = ln(gdp)
gen lnco2emis = ln(co2emissions)
gen lnco2sa1 = ln(co2emissionssa1)

save filtertestdata, replace


*Merge in with gasoline and oil price data
clear
insheet using "C:\Users\gaheutel\Documents\Economics\RBCPollution\Empirical\gasoilpricemonthly.txt", tab
gen year = substr(date,7,2)
drop if year == ""
gen month = substr(date,1,2)
destring year month, replace
replace year = 1900+year
replace year = 100+year if year < 1950
drop date

merge year month using "C:\Users\gaheutel\Documents\Economics\RBCPollution\Empirical\CarbonBMB\filtertestdata.dta", unique sort
drop _merge

gen lnoilprice = ln(oilprice)
gen lngasprice = ln(gasprice)

save filtertestdata, replace


*Merge in with temp data
clear
insheet using "C:\Users\gaheutel\Documents\Economics\RBCPollution\Empirical\MonthlyTemp.txt", tab
rename average averagetemp

merge year month using "C:\Users\gaheutel\Documents\Economics\RBCPollution\Empirical\CarbonBMB\filtertestdata.dta", unique sort
drop _merge

*Seasonally adjust average temp
sum averagetemp, meanonly
local mu = r(mean)
forvalues i=1/11 {
gen qseas`i' = (month(dofm(t))==`i')
}
regress averagetemp qseas*
predict double averagetempsa, residual
replace averagetempsa = averagetempsa + `mu'
drop qseas*

save filtertestdata, replace


*Merge in with employment data
clear
insheet using "C:\Users\gaheutel\Documents\Economics\RBCPollution\Empirical\MonthlyEmployment.txt", tab
rename v1 date
rename v2 employment
gen year = substr(date,7,2)
drop if year == ""
gen month = substr(date,1,2)
destring year month, replace
replace year = 1900+year
replace year = 100+year if year < 1920
drop date
gen lnemployment = ln(employment)

merge year month using "C:\Users\gaheutel\Documents\Economics\RBCPollution\Empirical\CarbonBMB\filtertestdata.dta", unique sort
drop if _merge ~= 3
drop _merge

save filtertestdata, replace

sort t
*Regressions on non-seasonally-adjusted data using sarima
arima lnco2emis lngdp, arima(1,1,1) sarima(0,1,1,12)
outreg2 using varresults2monthly, replace word

*Regressions on seasonally adjusted data w/ arima
arima lnco2sa1 lngdp, arima(1,1,2)
outreg2 using varresults2monthly, append word


*detrend w/ hpfilter
hprescott lngdp, smooth(129600) stub(HP)
hprescott lnco2sa1, smooth(129600) stub(HP)

*detrend w/ baxter king filter
bking lngdp, plo(18) phi(96) k(48) stub(BK)
bking lnco2sa1, plo(18) phi(96) k(48) stub(BK)

*detrend w/ Christiano Fitzgerald filter
cfitzrw lngdp, plo(18) phi(96) stub(CF)
cfitzrw lnco2sa1, plo(18) phi(96) stub(CF)

*detrend w/ Butterworth filter
butterworth lngdp, freq(48) stub(BW)
butterworth lnco2sa1, freq(48) stub(BW)

newey HP_lnco2sa1_1 HP_lngdp_1, lag(2) noconst
outreg2 using varresults2monthly, append word
newey BK_lnco2sa1_1 BK_lngdp_1, lag(2) noconst
outreg2 using varresults2monthly, append word
newey CF_lnco2sa1_1 CF_lngdp_1, lag(2) noconst
outreg2 using varresults2monthly, append word
newey BW_lnco2sa1_1 BW_lngdp_1, lag(2) noconst
outreg2 using varresults2monthly, append word


******
*Now do everything w/ quarterly aggregation

drop HP* CF* BW* BK*
tscollap  (sum) gdp co2emissions co2emissionssa1 employment (mean) gasprice oilprice averagetemp averagetempsa, to(q)

gen lngdp = ln(gdp)
gen lnco2emis = ln(co2emissions)
gen lnco2sa1 = ln(co2emissionssa1)
gen lntemp = ln(averagetemp)
gen lntempsa = ln(averagetempsa)
gen lnemployment = ln(employment)
gen lngasprice = ln(gasprice)
gen lnoilprice = ln(oilprice)

rename q_q t

save filtertestdataq.dta, replace

*Merge w/ investment/capital stock data
clear
insheet using "C:\Users\gaheutel\Documents\Economics\RBCPollution\Empirical\QuarterlyInvestment.txt", tab
rename v1 date
rename v2 investment
gen year = substr(date,1,4)
drop if year == ""
gen quarter = substr(date,6,1)
destring year quarter, replace
drop date
gen t = (year-1960)*4 + (quarter-1)
tsset t, q
drop year quarter
merge t using "C:\Users\gaheutel\Documents\Economics\RBCPollution\Empirical\CarbonBMB\filtertestdataq.dta", unique
save filtertestdataq.dta, replace

gen lninvestment = ln(investment)

*Regressions on non-seasonally-adjusted data using sarima
arima lnco2emis lngdp, arima(1,1,1) sarima(0,1,1,4)
outreg2 using varresults2quarterly, replace word

*Regressions on seasonally adjusted data w/ arima
arima lnco2sa1 lngdp, arima(1,1,2)
outreg2 using varresults2quarterly, append word

*detrend w/ hpfilter
hprescott lngdp, smooth(1600) stub(HP)
hprescott lnco2sa1, smooth(1600) stub(HP)

*detrend w/ baxter king filter
bking lngdp, plo(6) phi(32) k(12) stub(BK)
bking lnco2sa1, plo(6) phi(32) k(12) stub(BK)

*detrend w/ Christiano Fitzgerald filter
cfitzrw lngdp, plo(6) phi(32) stub(CF)
cfitzrw lnco2sa1, plo(6) phi(32) stub(CF)

*detrend w/ Butterworth filter
butterworth lngdp, freq(24) stub(BW)
butterworth lnco2sa1, freq(24) stub(BW)

newey HP_lnco2sa1_1 HP_lngdp_1, lag(2) noconst
outreg2 using varresults2quarterly, append word
newey BK_lnco2sa1_1 BK_lngdp_1, lag(2) noconst
outreg2 using varresults2quarterly, append word
newey CF_lnco2sa1_1 CF_lngdp_1, lag(2) noconst
outreg2 using varresults2quarterly, append word
newey BW_lnco2sa1_1 BW_lngdp_1, lag(2) noconst
outreg2 using varresults2quarterly, append word
